import pyautogui as py
import pyttsx3 as sx3

def alert():
    py.alert('This is an alert box.')
    'OK'

def confirm():
    py.confirm('Shall I proceed?')
    'Cancel'

def screenshot():
    im1 = py.screenshot()
    im1.save('Screenshot.png')
    im2 = py.screenshot('Screenshot.png')
    sx3.speak('Screenshot file has been saved. In your abhinav folder.')

def write():
    print(input('Enter your words: '))

def speak():
    engine = sx3.init()
    engine.say(input('Enter the words that are to speaken: '))
    engine.runAndWait()

def sum(a1,a2):
    n = a1 + a2
    print('The result is:', n)

def sub(a1,a2):
    n = a1 - a2
    print('The result is:', n)

def mul(a1,a2):
    n = a1 * a2
    print('The result is:', n)

def div(a1,a2):
    n = a1 / a2
    print('The result is:', n)




from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.4'
DESCRIPTION = 'This package is made by me, means Abhinav Mishra'
LONG_DESCRIPTION = 'A package to perform arithmetic operations, in-build Text-to-speech program, Auto alert gui box and lots more. To download this module, go to your cmd(Command Prompt) or terminal and type the command given at the top. Hope you will like it!!'

# Setting up
setup(
    name="Abhinav",
    version=VERSION,
    author="Abhinav Mishra",
    author_email="abhinavkrishu007@gmail.com",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=['arithmetic', 'math', 'mathematics', 'pyautogui', 'pyttsx3', 'best', 'python', 'abhicoder','abhinav mishra', 'abhinav'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)